@@ -300,11 +300,10 @@ class WebDriver (ElementLocation):
 
         if self.webdriverName=="custom":
             #Gets custom driver object
-            self.driver=startupOptions['custom_driver']
+            driver=startupOptions['custom_driver']
 
         #Set driver
-        if self.webdriverName!="custom":
-            self.driver=driver
+        self.driver=driver
 
         #Init ElementLocation class
         super().__init__(driver,WebElement)
